@@ -23,7 +23,8 @@
 #include "config.h"
 #include <gnome.h>
 
-#include <libgnorba/gnorba.h>
+#include <bonobo-activation/bonobo-activation.h>
+#include <libbonobo.h>
 
 #include "orbit_daemon_glue.h"
 #include "queue_io.h"
@@ -617,14 +618,14 @@ gpilotd_corba_monitor_on(GNOME_Pilot_Daemon obj,
 			LOGEXN (my_ev);
 		} else {
 			LOG("Client seems ok");
-		}
-		tmpcb = CORBA_ORB_string_to_object(orb,(CORBA_char*)tmp_client_id,&my_ev); 
-		if(my_ev._major != CORBA_NO_EXCEPTION) {
-			LOG("**** Client appears to be disconnected...");
-			LOGEXN (my_ev);
-			g_assert_not_reached();
-		} else {
-			LOG("Client seems ok");
+			tmpcb = CORBA_ORB_string_to_object(orb,(CORBA_char*)tmp_client_id,&my_ev); 
+			if(my_ev._major != CORBA_NO_EXCEPTION) {
+				LOG("**** Client appears to be disconnected...");
+				LOGEXN (my_ev);
+				g_assert_not_reached();
+			} else {
+				LOG("Client seems ok");
+			}
 		}
 	}
 #endif
@@ -2045,6 +2046,7 @@ void gpilotd_corba_init(int *argc,
 	PortableServer_POA the_poa;
 	GNOME_Pilot_Daemon acc;
 	static gboolean object_initialised = FALSE;
+	Bonobo_RegistrationResult result;
 
 	if ( object_initialised ) return;
 
@@ -2052,10 +2054,7 @@ void gpilotd_corba_init(int *argc,
 
 	CORBA_exception_init(&ev);
 
-	orb = gnome_CORBA_init(PACKAGE,VERSION,
-			       argc,argv,
-			       GNORBA_INIT_SERVER_FUNC,&ev);
-	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
+	orb = bonobo_activation_orb_get();
 
 	*context = gpilot_context_new();
 	gpilot_context_init_user (*context);
@@ -2077,25 +2076,32 @@ void gpilotd_corba_init(int *argc,
 	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
 	g_message ("Activating CORBA server");
-	switch(goad_server_register(CORBA_OBJECT_NIL,acc,"gpilotd","object",&ev)) {
-	case -2:
-                /* FIXME: better handling here */
-		g_message(_("The gnome-pilot daemon is already running"));
-		exit (0);
+
+	result = bonobo_activation_active_server_register (
+		"OAFIID:GNOME_Pilot_Daemon", acc);
+	g_message ("bonobo_activation_active_server_register = %d", result);
+	switch (result) {
+	case Bonobo_ACTIVATION_REG_SUCCESS:
 		break;
-	case -1:
-                /* FIXME: better handling here */
-		g_print("GOAD Name server failure\n");
+	case Bonobo_ACTIVATION_REG_NOT_LISTED:
+		g_message ("Cannot register gpilotd because not listed");
+		exit (1);
+	case Bonobo_ACTIVATION_REG_ALREADY_ACTIVE:
+		g_message ("Cannot register gpilotd because already active");
+		exit (0);
+	case Bonobo_ACTIVATION_REG_ERROR:
+	default:
+		g_message ("Cannot register gpilotd because we suck");
 		exit (1);
-		break;
 	}
-	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
 	CORBA_Object_release(acc, &ev);
 	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
-	ORBit_custom_run_setup(orb, &ev);
-	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
+	if (!bonobo_init (argc, argv)) {
+		g_message ("init_bonobo(): could not initialize Bonobo");
+		exit (EXIT_FAILURE);
+	}
 }
 
 
